"use strict";

exports.__esModule = true;
exports.withBreakpoints = exports.ResponsiveWrapper = exports.ResponsiveConsumer = exports.Responsive = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _breakpoints = require("../helpers/breakpoints");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _createForOfIteratorHelperLoose(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (it) return (it = it.call(o)).next.bind(it); if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; return function () { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var initialBreakpoint = {
  name: 'default',
  value: 0
};

var _React$createContext = /*#__PURE__*/_react.default.createContext(initialBreakpoint),
    Provider = _React$createContext.Provider,
    Consumer = _React$createContext.Consumer;

var ResponsiveConsumer = Consumer;
exports.ResponsiveConsumer = ResponsiveConsumer;

var withBreakpoints = function withBreakpoints(Comp) {
  return function (props) {
    return /*#__PURE__*/_react.default.createElement(ResponsiveConsumer, null, function (breakpoint) {
      return /*#__PURE__*/_react.default.createElement(Comp, _extends({
        breakpoint: breakpoint,
        isGreaterThan: function isGreaterThan(value) {
          return breakpointIsGreaterThan(value, breakpoint.value);
        },
        isLessThan: function isLessThan(value) {
          return breakpointIsLessThan(value, breakpoint.value);
        }
      }, props));
    });
  };
};

exports.withBreakpoints = withBreakpoints;

var ResponsiveWrapper = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ResponsiveWrapper, _Component);

  function ResponsiveWrapper(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.state = _extends({}, initialBreakpoint);
    _this.mediaQueries = [];
    return _this;
  }

  var _proto = ResponsiveWrapper.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this2 = this;

    this.mediaQueries = Object.keys(_breakpoints.breakpoints).map(function (key) {
      var query = window.matchMedia("(min-width: " + _breakpoints.breakpoints[key] + "px)");
      query.breakpoint = _breakpoints.breakpoints[key];
      query.name = key;
      query.addListener(function () {
        return _this2.dispatchActiveQuery();
      });
      return query;
    });
    this.dispatchActiveQuery();
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var _this3 = this;

    for (var _iterator = _createForOfIteratorHelperLoose(this.mediaQueries), _step; !(_step = _iterator()).done;) {
      var query = _step.value;
      query.removeListener(function () {
        return _this3.dispatchActiveQuery();
      });
    }
  };

  _proto.dispatchActiveQuery = function dispatchActiveQuery() {
    var activeQuery = this.mediaQueries.reduce(function (prev, curr) {
      return curr.matches ? curr : prev && prev.matches ? prev : null;
    });
    var breakpointName = activeQuery ? activeQuery.name : 'default';
    var breakpointSize = activeQuery && activeQuery.breakpoint;
    this.setState({
      name: breakpointName,
      value: breakpointSize
    });
  };

  _proto.render = function render() {
    return /*#__PURE__*/_react.default.createElement(Provider, {
      value: _extends({}, this.state)
    }, /*#__PURE__*/_react.default.createElement(_react.Fragment, null, this.props.children));
  };

  return ResponsiveWrapper;
}(_react.Component);

exports.ResponsiveWrapper = ResponsiveWrapper;
var propTypes = {
  unmount: _propTypes.default.bool,
  showFor: _propTypes.default.oneOf(['small', 'medium', 'large', 'xlarge']),
  hideFor: _propTypes.default.oneOf(['small', 'medium', 'large', 'xlarge']),
  children: _propTypes.default.any
};

var Responsive = /*#__PURE__*/function (_Component2) {
  _inheritsLoose(Responsive, _Component2);

  function Responsive() {
    return _Component2.apply(this, arguments) || this;
  }

  var _proto2 = Responsive.prototype;

  _proto2.render = function render() {
    var _this$props = this.props,
        unmount = _this$props.unmount,
        showFor = _this$props.showFor,
        hideFor = _this$props.hideFor,
        children = _this$props.children;

    var content = function content(breakpoint) {
      if (showFor && breakpointIsLessThan(showFor, breakpoint.value) || hideFor && breakpointIsGreaterThan(hideFor, breakpoint.value)) {
        if (unmount) {
          return null;
        } else {
          return /*#__PURE__*/_react.default.createElement("div", {
            style: {
              display: 'none'
            }
          }, children);
        }
      } else {
        return children;
      }
    };

    return /*#__PURE__*/_react.default.createElement(Consumer, null, function (breakpoint) {
      return content(breakpoint);
    });
  };

  return Responsive;
}(_react.Component);

exports.Responsive = Responsive;
Responsive.propTypes = propTypes;

var breakpointIsGreaterThan = function breakpointIsGreaterThan(breakpointToCompare, currentBreakpointSize) {
  var comparison = typeof breakpointToCompare === 'string' ? _breakpoints.breakpoints[breakpointToCompare] : breakpointToCompare;
  return currentBreakpointSize === null || currentBreakpointSize >= comparison;
};

var breakpointIsLessThan = function breakpointIsLessThan(breakpointToCompare, currentBreakpointSize) {
  var comparison = typeof breakpointToCompare === 'string' ? _breakpoints.breakpoints[breakpointToCompare] : breakpointToCompare;
  return currentBreakpointSize !== null && currentBreakpointSize < comparison;
};